-- settings.lua
-- Written by Habna


-- **v Load / update / set default settings v**
function LoadSettings()
	InitXPos, InitYPos = 17, 33; --> ** Initial X & Y position of the first Item in the HugeBag **
	WinWidth, WinHeight = 460, 300;
	edgePadding = 15; --> ** HugeBag initial edgePadding value **
	LockLabel = self; --> ** Label that prevents from moving the window cause it's located at top
	ClicX, ClicY = 0, 0; --> To know the x,y coord when mouse button was clic

	settings = Turbine.PluginData.Load( Turbine.DataScope.Character, "HugeBagWindowSettings" );

	if settings == nil then
		WinLocX = Turbine.UI.Display.GetWidth() - edgePadding - WinWidth;
		WinLocY = Turbine.UI.Display.GetHeight() - edgePadding - WinHeight - 55;
		bcAlpha, bcRed, bcGreen, bcBlue = 1, 0, 0, 0;
		LeftPos, MidPos, RightPos = 35, 85, 135;
		SortLeft, MergeLeft, SearchLeft = LeftPos, MidPos, RightPos;
		HorizontalOrientation = true;
		ReverseFill = false;
		ButtonsPos = "left";
		ButtonAtLeft = true;
		InverseMerge = false;
		ShowButton = true;
		ButtonAtTop = false;
		HideWEsc = true;
		zOrder = true;
		LockPosition = false;
		LockSize = false;
		ShowTitle = true;
		ShowSkin = true;
		StartVisible = false;
		HBWasVisible = false;
		ShowSlotsInfo = true;
		SaveSettings();
	end

	WinWidth = tonumber(settings.Size.W);
	WinHeight = tonumber(settings.Size.H);

	WinLocX = tonumber(settings.Location.X);
	WinLocY = tonumber(settings.Location.Y);

	-- Need to go out of bound when no skin on HugeBag
	-- **v Replace HugeBag if out of the screen on load v**
	--if ( WinLocX + WinWidth ) > screenWidth then WinLocX = screenWidth - WinWidth end
	--if ( WinLocY + WinHeight ) > screenHeight then WinLocY = screenHeight - WinHeight end
	-- **^
	
	bcAlpha = tonumber(settings.BackColor.A);
	bcRed = tonumber(settings.BackColor.R);
	bcGreen = tonumber(settings.BackColor.G);
	bcBlue = tonumber(settings.BackColor.B);
	
	StartVisible = settings.Options.StartVisible;
	ShowSlotsInfo = settings.Options.ShowSlotsInfo;
	HideWEsc = settings.Options.HideWEsc;
	LockPosition = settings.Options.LockPosition;
	LockSize = settings.Options.LockSize;
	ShowSkin = settings.Options.ShowSkin;
	ShowTitle = settings.Options.ShowTitle;
	zOrder = settings.Options.AlwaysOnTop;
	
	InverseMerge = settings.Button.InverseMerge;
	ShowButton = settings.Button.ShowButton;
	ButtonAtTop = settings.Button.AtTop;
	ButtonAtLeft = settings.Button.AtLeft;
	
	MidPos = tonumber(settings.Button.Position.MidPos);
	SortLeft = tonumber(settings.Button.Position.Sort);
	SearchLeft = tonumber(settings.Button.Position.Search);
	MergeLeft = tonumber(settings.Button.Position.Merge);
	LeftPos = MidPos - 50;
	RightPos = MidPos + 50;
	
	HorizontalOrientation = settings.Items.HorizontalOrientation;
	ReverseFill = settings.Items.ReverseFill;

	--if settings.Version == nil then	settings.Version = Version; end

	--if settings.WasVisible == nil then settings.WasVisible = StartVisible; end

	WasVisible = settings.WasVisible;

	--Turbine.PluginData.Save( Turbine.DataScope.Character, "HugeBagWindowSettings", settings );
end
-- **^
-- **v Save settings v**
function SaveSettings()
	settings = {};
	settings.Version = Version;
	settings.WasVisible = WasVisible;

	settings.Location = {};
	settings.Location.X = tostring(WinLocX);
	settings.Location.Y = tostring(WinLocY);

	settings.Size = {};
	settings.Size.W = tostring(WinWidth);
	settings.Size.H = tostring(WinHeight);

	settings.Options = {};
	settings.Options.StartVisible = StartVisible;
	settings.Options.ShowSlotsInfo = ShowSlotsInfo;
	settings.Options.HideWEsc = HideWEsc;
	settings.Options.LockPosition = LockPosition;
	settings.Options.LockSize = LockSize;
	settings.Options.ShowSkin = ShowSkin;
	settings.Options.ShowTitle = ShowTitle;
	settings.Options.AlwaysOnTop = zOrder;

	settings.BackColor = {};
	settings.BackColor.A = string.format("%.3f", bcAlpha);
	settings.BackColor.R = string.format("%.3f", bcRed);
	settings.BackColor.G = string.format("%.3f", bcGreen);
	settings.BackColor.B = string.format("%.3f", bcBlue);
	
	settings.Button = {};
	settings.Button.InverseMerge = InverseMerge;
	settings.Button.ShowButton = ShowButton;
	settings.Button.AtTop = ButtonAtTop;
	settings.Button.AtLeft = ButtonAtLeft;
	
	settings.Button.Position = {};
	settings.Button.Position.MidPos = tostring(MidPos);
	settings.Button.Position.Sort = tostring(SortLeft);
	settings.Button.Position.Search = tostring(SearchLeft);
	settings.Button.Position.Merge = tostring(MergeLeft);

	settings.Items = {};
	settings.Items.HorizontalOrientation = HorizontalOrientation;
	settings.Items.ReverseFill = ReverseFill;

	Turbine.PluginData.Save( Turbine.DataScope.Character, "HugeBagWindowSettings", settings );

	Modesettings = {};
	Modesettings.Widget = Widget;
	Turbine.PluginData.Save( Turbine.DataScope.Character, "HugeBagMode", Modesettings );
end
-- **^
-- **v Reset Location and Size Settings v**
function ResetLSSettings()
	WinWidth, WinHeight = 460, 300;
	wHugeBag:SetSize( WinWidth, WinHeight );
	wHugeBag:SetPosition( Turbine.UI.Display.GetWidth() - edgePadding - WinWidth, Turbine.UI.Display.GetHeight() - edgePadding - WinHeight - 55 );
	WinLocX, WinLocY = wHugeBag:GetPosition();
	wHugeBag:SetVisible( true );
	if not ButtonAtLeft then
		if ( self:GetWidth() >= 218 ) then
			ButtonsLeft();
			ButtonsRight();
		end
	end
	PerformLayout();
	PrintTitle();
	SaveSettings();
	Turbine.Shell.WriteLine( "HugeBag: My location and size was set back to default" );
end
-- **^
-- **v Reset All Settings v**
function ResetSettings()
	StartVisible = false;
	HBWasVisible = false;
	ShowSlotsInfo = true;
	HideWEsc = true;
	LockPosition = true;
	LockHugeBagPosition();
	LockSize = true;
	LockHugeBagSize();
	Widget = Widget;
	WinWidth, WinHeight = 460, 300;
	wHugeBag:SetSize( WinWidth, WinHeight );
	wHugeBag:SetPosition( Turbine.UI.Display.GetWidth() - edgePadding - WinWidth, Turbine.UI.Display.GetHeight() - edgePadding - WinHeight - 55 );
	WinLocX, WinLocY = wHugeBag:GetPosition()
	bcAlpha, bcRed, bcGreen, bcBlue = 1, 0, 0, 0;
	wHugeBag.itemListBox:SetBackColor( Turbine.UI.Color( bcAlpha, bcRed, bcGreen, bcBlue ) );
	wHugeBag:SetVisible( true );
	ShowSkin = false;
	ToggleSkin();
	ShowTitle = false;
	ToggleTitle();
	ShowButton = false;
	ToggleButton();
	ButtonAtTop = false;
	ButtonAtLeft = true;
	ButtonsPos = "left";
	InverseMerge = false;
	LeftPos, MidPos, RightPos = 35, 85, 135;
	TopPos = wHugeBag:GetHeight() - 13;
	SortLeft, MergeLeft, SearchLeft = LeftPos, MidPos, RightPos;
	HorizontalOrientation = true;
	--ReverseFill = false;
	zOrder = true;
	PerformLayout();
	PrintTitle();
	SaveSettings();
	Turbine.Shell.WriteLine( "HugeBag: All my settings was set back to default" );
end
-- **^